==> sardana_2.6.2+dfsg.orig.tar.xz: sardana-2.6.2+dfsg/doc/source/sep/index.md <==
Sardana Enhancement Proposals
=============================

This is the main index of the Sardana Enhancement Proposals (SEP).

Each proposal should be in a separate file and be linked in the following table

Proposals list
--------------

  Link        |  status   |        Title
  ------------| --------- | ---------------------------------------------------------
  [SEP0][]    | OBSOLETE     | Introducing Sardana Enhancement Proposal
  [SEP1][]    | OBSOLETE     | Reorganization of code repos
  [SEP2][]    | CANDIDATE     | Improve integration of 1D and 2D experimental channels
  [SEP3][]    | REJECTED (handled in [#297][]) | Adapt to [TEP3][] (Tango-independent taurus.core)
  [SEP4][]    | ACCEPTED     | HKL integration
  [SEP5][]    | ACCEPTED     | Implementation of tests infrastructure
  [SEP6][]    | ACCEPTED     | Continuous Scan Implementation
  [SEP7][]    | OBSOLETE     | Code contribution workflow
  [SEP8][]    | CANDIDATE     | Remove from Taurus objects the direct Logger dependence
  [SEP9][]    | ACCEPTED     | Compact Read+Write widgets in Taurus
  [SEP10][]    | OBSOLETE     | Taurus separation
  [SEP11][]    | ACCEPTED     | Direct load of .ui files
  [SEP12][]    | CANDIDATE     | Use python Enum instead of taurus Enumeration
  [SEP13][]    | REJECTED (moved to [TEP13][])     | Unified plugins support in Taurus & Sardana
  [SEP14][]    | DRAFT     | MSENV taurus schema
  [SEP15][]   | ACCEPTED     | Moving Sardana to Github
  [SEP16][]   | DRAFT     | Plugins (controllers, macros, etc.) register
  [SEP17][]   | DRAFT     | Ongoing acquisition formalization and implementation 
  [SEP18][]   | ACCEPTED     | Extend acquisition and synchronization concepts for SEP2 needs




[SEP0]: http://www.sardana-controls.org/sep/?SEP0.md
[SEP1]: http://www.sardana-controls.org/sep/?SEP1.md
[SEP2]: https://github.com/reszelaz/sardana/blob/sep2/doc/source/sep/SEP2.md
[SEP3]: http://www.sardana-controls.org/sep/?SEP3.md
[SEP4]: http://www.sardana-controls.org/sep/?SEP4.md
[SEP5]: http://www.sardana-controls.org/sep/?SEP5.md
[SEP6]: http://www.sardana-controls.org/sep/?SEP6.md
[SEP7]: http://www.sardana-controls.org/sep/?SEP7.md
[SEP8]: http://www.sardana-controls.org/sep/?SEP8.md
[SEP9]: http://www.sardana-controls.org/sep/?SEP9.md
[SEP10]: http://www.sardana-controls.org/sep/?SEP10.md
[SEP11]: http://www.sardana-controls.org/sep/?SEP11.md
[SEP12]: http://www.sardana-controls.org/sep/?SEP12.md
[SEP13]: http://www.sardana-controls.org/sep/?SEP13.md
[SEP14]: http://www.sardana-controls.org/sep/?SEP14.md
[SEP15]: http://www.sardana-controls.org/sep/?SEP15.md
[SEP16]: https://github.com/reszelaz/sardana/blob/sep16/doc/source/sep/SEP16.md
[SEP17]: https://github.com/reszelaz/sardana/blob/sep17/doc/source/sep/SEP17.md
[SEP18]: http://www.sardana-controls.org/sep/?SEP18.md


[TEP3]: http://www.taurus-scada.org/tep/?TEP3.md
[TEP13]: http://www.taurus-scada.org/tep/?TEP13.md


[#297]: https://github.com/sardana-org/sardana/issues/297

==> sardana_3.0.3.orig.tar.xz: sardana-3.0.3/doc/source/sep/index.md <==
Sardana Enhancement Proposals
=============================

This is the main index of the Sardana Enhancement Proposals (SEP).

Each proposal should be in a separate file and be linked in the following table

Proposals list
--------------

  Link        |  status   |        Title
  ------------| --------- | ---------------------------------------------------------
  [SEP0][]    | OBSOLETE     | Introducing Sardana Enhancement Proposal
  [SEP1][]    | OBSOLETE     | Reorganization of code repos
  [SEP2][]    | ACCEPTED     | Improve integration of 1D and 2D experimental channels
  [SEP3][]    | REJECTED (handled in [#297][]) | Adapt to [TEP3][] (Tango-independent taurus.core)
  [SEP4][]    | ACCEPTED     | HKL integration
  [SEP5][]    | ACCEPTED     | Implementation of tests infrastructure
  [SEP6][]    | ACCEPTED     | Continuous Scan Implementation
  [SEP7][]    | OBSOLETE     | Code contribution workflow
  [SEP8][]    | CANDIDATE     | Remove from Taurus objects the direct Logger dependence
  [SEP9][]    | ACCEPTED     | Compact Read+Write widgets in Taurus
  [SEP10][]    | OBSOLETE     | Taurus separation
  [SEP11][]    | ACCEPTED     | Direct load of .ui files
  [SEP12][]    | CANDIDATE     | Use python Enum instead of taurus Enumeration
  [SEP13][]    | REJECTED (moved to [TEP13][])     | Unified plugins support in Taurus & Sardana
  [SEP14][]    | DRAFT     | MSENV taurus schema
  [SEP15][]   | ACCEPTED     | Moving Sardana to Github
  [SEP16][]   | ACCEPTED    | Plugins (controllers, macros, etc.) catalogue
  [SEP17][]   | DRAFT     | Ongoing acquisition formalization and implementation 
  [SEP18][]   | ACCEPTED     | Extend acquisition and synchronization concepts for SEP2 needs
  [SEP19][]   | DRAFT        | Refactor plugin system




[SEP0]: http://www.sardana-controls.org/sep/?SEP0.md
[SEP1]: http://www.sardana-controls.org/sep/?SEP1.md
[SEP2]: http://www.sardana-controls.org/sep/?SEP2.md
[SEP3]: http://www.sardana-controls.org/sep/?SEP3.md
[SEP4]: http://www.sardana-controls.org/sep/?SEP4.md
[SEP5]: http://www.sardana-controls.org/sep/?SEP5.md
[SEP6]: http://www.sardana-controls.org/sep/?SEP6.md
[SEP7]: http://www.sardana-controls.org/sep/?SEP7.md
[SEP8]: http://www.sardana-controls.org/sep/?SEP8.md
[SEP9]: http://www.sardana-controls.org/sep/?SEP9.md
[SEP10]: http://www.sardana-controls.org/sep/?SEP10.md
[SEP11]: http://www.sardana-controls.org/sep/?SEP11.md
[SEP12]: http://www.sardana-controls.org/sep/?SEP12.md
[SEP13]: http://www.sardana-controls.org/sep/?SEP13.md
[SEP14]: http://www.sardana-controls.org/sep/?SEP14.md
[SEP15]: http://www.sardana-controls.org/sep/?SEP15.md
[SEP16]: http://www.sardana-controls.org/sep/?SEP16.md
[SEP17]: https://github.com/reszelaz/sardana/blob/sep17/doc/source/sep/SEP17.md
[SEP18]: http://www.sardana-controls.org/sep/?SEP18.md
[SEP19]: https://github.com/reszelaz/sardana/blob/sep19/doc/source/sep/SEP19.md

[TEP3]: http://www.taurus-scada.org/tep/?TEP3.md
[TEP13]: http://www.taurus-scada.org/tep/?TEP13.md


[#297]: https://github.com/sardana-org/sardana/issues/297
